Struct Cosmology

pub struct Cosmology {
    pub omega_m: f64,
    pub omega_k: f64,
    pub omega_l: f64,
    pub h0: f64,
}
A Flat lambda CDM cosmology object. @param redshift_array an array of multiple redshift values. @param omega_m Mass density (often 0.3 in LCDM). @param omega_k Effective mass density of relativistic particles (often 0. in LCDM). @param omega_l Effective mass density of dark energy (often 0.7 in LCDM). @param h0 H0 = 100 * h.

Fields

omega_m: f64

Mass density (often 0.3 in LCDM).

omega_k: f64

Effective mass density of relativistic particles (often 0 in LCDM).

omega_l: f64

Effective mass density of dark energy (often 0.7 in LCDM).

h0: f64

Implementations

Source

impl Cosmology

pub fn e_func(&self, z: f64) -> f64

Calculates the e function, E(z) that is often used in cosmology calculates.

pub fn hubble_distance(&self) -> f64

Calculates the hubble distance which is just the speed of light divided by the hubble constant.

pub fn h_at_z(&self, z: f64) -> f64

Calculates the H(z) for a given z.

pub fn rho_critical(&self, z: f64, distance_type: DistanceType) -> f64

The critical density of the universe for either Angular or Comoving scales.

pub fn comoving_distance(&self, z: f64) -> f64

The co-moving distance at a given z.

pub fn inverse_codist(&self, distance: f64) -> f64

The redshift at a given co-moving distance.

pub fn comoving_transverse_distance(&self, z: f64) -> f64

comoving transverse distance at a given redshift. This is just the comoving distance when k = 0.

pub fn distance_modulus(&self, z: f64) -> f64

The distance modulus at a given redshift. Used to convert apparent mag to absolute mag. M = m - D.

pub fn mvir_to_rvir(&self, solar_mass: f64, z: f64) -> f64

The virial radius for the given virial mass.

pub fn mvir_to_sigma(&self, solar_mass: f64, z: f64) -> f64

The virial velocity distribution for the given viral mass.